@@ -16,14 +16,13 @@
 # $Revision: 10303 $
 
 import os
-import sys
 import re
 import hashlib
 import json
 
 from lxml import etree
 from lxml.html.soupparser import parse
-from django.core.management.base import BaseCommand, CommandError
+from django.core.management.base import BaseCommand
 from django.template.loader import get_template
 
 from Zephyrus.boilerplate.management.commands import (
@@ -34,17 +33,23 @@ logger = createLogger(__name__, "BuildBoilerplate2.log")
 
 # inside -----------------------------------------------------------------------
 # 段落 tag
-TEXT_TAGS = ['h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'p',]
+TEXT_TAGS = ['h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'p', 'details', 'address',]
 
 # 視覺 tag
-VISUAL_TAGS = ['em', 'strong', 'b', 'small',]
+VISUAL_TAGS = [
+    'em', 'strong', 'b', 'small', 'var', 'kbd', 'samp', 
+    'pre', 'dfn', 'code', 'cite', 'del', 'ins', 'sub', 'sup', 'i',
+]
 
 ADD_PLACEHOLDER_TO_INSIDE_TAGS = ['span', 'button',] 
 
 ALL_INSIDE_TAGS = TEXT_TAGS + VISUAL_TAGS + ADD_PLACEHOLDER_TO_INSIDE_TAGS
 
 # outside ----------------------------------------------------------------------
-ADD_PLACEHOLDER_TO_OUTSIDE_TAGS = ['img', 'ul', 'a', 'table', 'ol', 'form',] 
+ADD_PLACEHOLDER_TO_OUTSIDE_TAGS = [
+    'img', 'ul', 'a', 'table', 'ol', 'form', 'dl', 
+    'blockquote', 'q', 'abbr', 'article', 
+] 
 
 ALL_OUTSIDE_TAGS = ADD_PLACEHOLDER_TO_OUTSIDE_TAGS
 
@@ -53,7 +58,16 @@ BLOCK_TAGS = ['div',]
 
 # special ----------------------------------------------------------------------
 SKIP_BLOCK_TAG = ['a', 'span',] + VISUAL_TAGS
-ADD_COMMENT_TO_PREVIOUS = ['img',]
+ADD_COMMENT_TO_PREVIOUS = ['img', 'a',]
+JUMP_OFF_TAG = ['script', 'style', 'link',]
+CHANGE_WORD = {
+    '{': '&#123;',
+    '}': '&#125;',
+    '&#123;': '&#123;',
+    '&#125;': '&#125;',
+}
+EXCEPT_TAGS = ['nav', 'section', ]
+NO_INDENT = ['pre', 'code',]
 
 # comment ----------------------------------------------------------------------
 COMMENT = "The template was modified by Nuwainfo.com"
@@ -67,20 +81,20 @@ CMS_BODY_FRONT_TAG = "{% cms_toolbar %}"
 CMS_BODY_BACK_TAG = "{% render_block 'js' %}"
 
 CMS_PAGE_ATTRS_COMMENT = '''
-CMS page attribute
-Slug: {% page_attribute "slug" %}
-Changed_date: {% page_attribute "changed_date" %}
-Changed_by: {% page_attribute "changed_by" %}
-'''
+    CMS page attribute
+    Slug: {% page_attribute "slug" %}
+    Changed_date: {% page_attribute "changed_date" %}
+    Changed_by: {% page_attribute "changed_by" %}
+    '''
 
 ALL_TAGS = ALL_INSIDE_TAGS + ALL_OUTSIDE_TAGS + BLOCK_TAGS
 
 class Command(BaseCommand):
 
     help = 'Add placeholder to templates'
+    args = '<destination folder>'
 
     def add_arguments(self, parser):
-        parser.add_argument('path', type=str, help="destination folder")
         parser.add_argument(
             '-d', '--debug', 
             action='store_false',
@@ -90,7 +104,7 @@ class Command(BaseCommand):
         if len(args) < 1:
             path = TEMPLATES_DIR_PATH
         else:
-            path = options['path']
+            path = args[0]
 
         debug = options['debug']
 
@@ -105,21 +119,25 @@ class Command(BaseCommand):
         fileDict.update(templateDict)
        
         for root, dirs, files in os.walk(path):
-            for file in files:
-                name = file
-                file = os.path.join(root, file)
-                logger.info(file)
+            for htmlfile in files:
+                name = htmlfile
+                htmlfile = os.path.join(root, htmlfile)
+                logger.info(htmlfile)
 
                 # preprocess ===================================================
-                commentDict = self.findComment(file)
-
+                commentDict = self.findComment(htmlfile)
+                self.replaceExceptTags(htmlfile)
+                
                 # process lxml etree ===========================================
-                with open(file) as f:
+                with open(htmlfile) as f:
                     if not f.name.endswith(".html"):
                         continue
 
                     # etree ----------------------------------------------------
                     page = parse(f)
+                    
+                    # replace word
+                    self.changeWordToMd5(page)
 
                     # build placeholder
                     self.buildPlaceholder(page, name, debug=debug)
@@ -130,14 +148,20 @@ class Command(BaseCommand):
                     # deal with file path
                     self.replaceKeyword(page, fileDict)
 
+                    for tag in page.iter(tag='html'):
+                        html = tag
+                    self.indent(html)
+
                     # write file
-                    page.write(file, method='html', pretty_print=True)
+                    page.write(htmlfile, method='html', pretty_print=True)
 
                 # endprocess ===================================================
-                self.fixStaticTemplate(file, fileDict)
-                self.fixComment(file, commentDict)
+                self.fixStaticTemplate(htmlfile, fileDict)
+                self.fixComment(htmlfile, commentDict)
+                self.changeMd5ToWord(htmlfile)
+                self.fixExceptTags(htmlfile)
 
-                logger.info(file + " is OK!")
+                logger.info(htmlfile + " is OK!")
 
         logger.info('ALL OK!')
 
@@ -173,15 +197,15 @@ class Command(BaseCommand):
                 continue
 
             i = tagDict.get(ele.tag, 1)
-            id = "%s-%s-%d" % (filename, ele.tag, i)
+            placeholderId = "%s-%s-%d" % (filename, ele.tag, i)
             tagDict[ele.tag] = i + 1
             
             if ele.tag in BLOCK_TAGS:
-                self.buildBlockTagPlaceholder(ele, id)
+                self.buildBlockTagPlaceholder(ele, placeholderId)
             elif ele.tag in ALL_INSIDE_TAGS:
-                self.buildInsidePlaceholder(ele, id)
+                self.buildInsidePlaceholder(ele, placeholderId)
             elif ele.tag in ALL_OUTSIDE_TAGS:
-                self.buildOutsidePlaceholder(ele, id)
+                self.buildOutsidePlaceholder(ele, placeholderId)
             else:
                 pass
 
@@ -216,6 +240,37 @@ class Command(BaseCommand):
 
 
     #----------------------------lxml etree ele---------------------------------
+    def indent(self, elem, level=0, indentNum=2):
+        if elem.tag in NO_INDENT:
+            return
+        i = "\n" + level * (indentNum * " ")
+
+        if len(elem):
+            if not elem.text or not elem.text.strip():
+                elem.text = i + (indentNum * " ")
+            else:
+                elem.text = i + (indentNum * " ") + \
+                    elem.text.strip() + i + (indentNum * " ")
+
+            for e in elem:
+                self.indent(e, level + 1)
+                if not e.tail or not e.tail.strip():
+                    e.tail = i + (indentNum * " ")
+                else:
+                    e.tail = i + (indentNum * " ") + \
+                        e.tail.strip() + i + (indentNum * " ")
+
+            if not e.tail or not e.tail.strip():
+                e.tail = i
+            else:
+                e.tail = i + (indentNum * " ") + e.tail.strip() + i
+        else:
+            if level and (not elem.tail or not elem.tail.strip()):
+                elem.tail = i
+            else:
+                elem.tail = i + (indentNum * " ") + elem.tail.strip() + i
+
+
     def parentHasMarked(self, ele):
         for ancestor in ele.iterancestors():
             boilerplateMark = ancestor.get('boilerplateMark')
@@ -223,10 +278,21 @@ class Command(BaseCommand):
                 return True
         return False
 
-    def buildInsidePlaceholder(self, ele, id):
+    def dealWithJumpOffTags(self, ele):
+        jumpOf = []
+        for child in ele.iterdescendants():
+            if child.tag in JUMP_OFF_TAG:
+                jumpOf.append(child)
+                child.getparent().remove(child)
+        for tag in reversed(jumpOf):
+            ele.addnext(tag)
+
+    def buildInsidePlaceholder(self, ele, placeholderId):
         if not ele.get('boilerplateMark') == 'T':
             return
 
+        self.dealWithJumpOffTags(ele)
+
         if not ele.text:
             ele.text = ''
 
@@ -234,22 +300,25 @@ class Command(BaseCommand):
             if ele[-1].tail is None:
                 ele[-1].tail = ''
             ele[-1].tail = ele[-1].tail + "{% endplaceholder %}"
-            ele.text = "{% placeholder " + "'%s' " % id + "or %}" + ele.text
+            ele.text = "{% placeholder " + "'%s' " % placeholderId + "or %}" + \
+                        ele.text
         else:
-            ele.text = "{% placeholder " + "'%s' " % id + "or %}" + \
+            ele.text = "{% placeholder " + "'%s' " % placeholderId + "or %}" + \
                         ele.text + "{% endplaceholder %}"
 
-    def buildOutsidePlaceholder(self, ele, id):
+    def buildOutsidePlaceholder(self, ele, placeholderId):
         if not ele.get('boilerplateMark') == 'T':
             return
 
+        self.dealWithJumpOffTags(ele)
+
         if ele.tail:
             ele.tail = "{% endplaceholder %}" + ele.tail
         else:
             ele.tail = "{% endplaceholder %}"
 
         if ele.tag in ADD_COMMENT_TO_PREVIOUS:
-            text = "CMS:%s" % id
+            text = "CMS:%s" % placeholderId
             comment = etree.Comment(text=text)
             ele.addprevious(comment)
 
@@ -260,12 +329,15 @@ class Command(BaseCommand):
             if parent.text == None:
                 parent.text = ''
             parent.text = \
-                parent.text + "{% placeholder " + "'%s' " % id + "or %}"
+                parent.text + "{% placeholder " + "'%s' " % placeholderId + \
+                "or %}"
         else:
             if previous.tail == None:
                 previous.tail = ''
             previous.tail = previous.tail + \
-                            "{% placeholder " + "'%s' " % id + "or %}"
+                            "{% placeholder " + "'%s' " % placeholderId + \
+                            "or %}"
+        
 
     def markBlockTag(self, ele):
         hasText = False
@@ -281,25 +353,33 @@ class Command(BaseCommand):
             else:
                 return
         if ele.text or hasText:
+            if not ele.text:
+                ele.text = ''
             if ele.text.strip() != '':
                 ele.set('boilerplateMark', 'T')
 
-    def buildBlockTagPlaceholder(self, ele, id):
+    def buildBlockTagPlaceholder(self, ele, placeholderId):
         boilerplateMark = ele.get('boilerplateMark')
 
         if boilerplateMark == 'T':
-            self.buildInsidePlaceholder(ele, id)
+            self.buildInsidePlaceholder(ele, placeholderId)
         else:
             index = 1
             if not ele.text == None:
                 if not ele.text.strip() == '':
-                    ele.text = "{% placeholder " + "'%s-text%d' " % (id, index) + "or %}" + ele.text + "{% endplaceholder %}"
+                    ele.text = \
+                        "{% placeholder " + \
+                        "'%s-text%d' " % (placeholderId, index) + "or %}" + \
+                        ele.text + "{% endplaceholder %}"
 
             for child in ele.getchildren():
                 if not child.tail == None:
                     if not child.tail.strip() == '':
                         index += 1
-                        child.tail = "{% placeholder " + "'%s-text%d' " % (id, index) + "or %}" + child.tail + "{% endplaceholder %}"
+                        child.tail = \
+                            "{% placeholder " + \
+                            "'%s-text%d' " % (placeholderId, index) + \
+                            "or %}" + child.tail + "{% endplaceholder %}"
 
     def addCMSTags(self, page):
         for tag in page.iter(tag='head'):
@@ -431,6 +511,18 @@ class Command(BaseCommand):
                             continue
                         newValue = value.replace(path, fileDict[path])
                         tag.set(name, newValue)
+                        
+    def changeWordToMd5(self, page):
+        for tag in page.iter():
+            if not tag.tag in ['script', 'style',]:
+                if tag.text:
+                    for key in CHANGE_WORD:
+                        tag.text = tag.text.replace(
+                            key, hashlib.md5(key).hexdigest())
+                if tag.tail:
+                    for key in CHANGE_WORD:
+                        tag.tail = tag.tail.replace(
+                            key, hashlib.md5(key).hexdigest())
 
     #--------------------------------file---------------------------------------
     def findComment(self, filePath):
@@ -475,3 +567,40 @@ class Command(BaseCommand):
 
         with open(filePath, 'w') as f:
             f.write(content)
+            
+    def changeMd5ToWord(self, filePath):
+        with open(filePath, 'r') as f:
+            content = f.read()
+        for key in CHANGE_WORD:
+            content = content.replace(
+                hashlib.md5(key).hexdigest(), CHANGE_WORD[key])
+        with open(filePath, 'w') as f:
+            f.write(content)
+
+    def replaceExceptTags(self, filePath):
+        with open(filePath, 'r') as f:
+            content = f.read()
+        for tag in EXCEPT_TAGS:
+            # aa 開頭是為了讓 attr 排在最前面
+            content = content.replace(
+                '<%s' % tag, "<div aaboilerplateorigintag=\"%s\" " % tag)
+            content = content.replace(
+                '</%s>' % tag, 
+                "</div><!--aaboilerplateorigintag=\"%s\"-->" % tag)
+        with open(filePath, 'w') as f:
+            f.write(content)
+
+    def fixExceptTags(self, filePath):
+        with open(filePath, 'r') as f:
+            content = f.read()
+        for tag in EXCEPT_TAGS:
+            replaceList = re.findall(
+                r"\</div>\n\s+\<!--aaboilerplateorigintag=\"%s\"--\>" % tag, 
+                content)
+            content = content.replace(
+                "div aaboilerplateorigintag=\"%s\"" % tag, '%s' % tag)
+
+            for replaceStr in replaceList:
+                content = content.replace(replaceStr, '</%s>' % tag)
+        with open(filePath, 'w') as f:
+            f.write(content)
