@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_templates.py 10521 2017-11-19 07:10:05Z Lavender $
+# $Id: build_templates.py 10541 2017-11-21 10:42:06Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-11-19 15:10:05 +0800 (週日, 19 十一月 2017) $
-# $Revision: 10521 $
+# $Date: 2017-11-21 18:42:06 +0800 (週二, 21 十一月 2017) $
+# $Revision: 10541 $
 
 import os
 import sys
@@ -121,7 +121,7 @@ class Command(BaseCommand):
                     "%s manage.py create_zip \"%s\"" % (sys.executable, dstPath))
             else:
                 error = os.system(
-                    "%s manage.py create_zip \"%s\" -o -n \"%s\"" % (
+                    "%s manage.py create_zip \"%s\" -o -n \"%s_theme\"" % (
                         sys.executable, dstPath, f))
             if not error == 0:
                 logger.error(
