@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: fix_template.py 10330 2017-10-01 01:54:54Z Lavender $
+# $Id: fix_template.py 10389 2017-10-22 05:43:34Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,16 +12,13 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-10-01 09:54:54 +0800 (週日, 01 十月 2017) $
-# $Revision: 10330 $
+# $Date: 2017-10-22 13:43:34 +0800 (週日, 22 十月 2017) $
+# $Revision: 10389 $
 
 import os
-import shutil
 import hashlib
 
-from django.core.management.base import BaseCommand, CommandError
-from django.conf import settings
-from cms.templatetags.cms_tags import *
+from django.core.management.base import BaseCommand
 
 from Zephyrus.boilerplate.management.commands import TEMPLATES_DIR_PATH
 from Zephyrus.boilerplate.management.commands import createLogger
@@ -44,9 +41,9 @@ class Command(BaseCommand):
         from django.template import Context
             
         fileList = os.listdir(TEMPLATES_DIR_PATH)
-        for file in fileList:
-            file = os.path.join(TEMPLATES_DIR_PATH, file)
-            logger.info(file)
+        for htmlfile in fileList:
+            htmlfile = os.path.join(TEMPLATES_DIR_PATH, htmlfile)
+            logger.info(htmlfile)
             # preprocess
             loadTagHash = hashlib.md5(
                 "{% load cms_tags menu_tags sekizai_tags %}"
@@ -57,7 +54,7 @@ class Command(BaseCommand):
                 "{% render_block 'css' %}").hexdigest()
             toolbarHash = "%s" % hashlib.md5(
                 "{% cms_toolbar %}").hexdigest()
-            with open(file, 'rb') as f:
+            with open(htmlfile, 'rb') as f:
                 text = f.read()
                 text = text.replace(
                     "{% load cms_tags menu_tags sekizai_tags %}"
@@ -68,10 +65,10 @@ class Command(BaseCommand):
                 text = text.replace("{% cms_toolbar %}", toolbarHash)
                 
             if options['overwrite']:
-                fileName = file
+                fileName = htmlfile
             else:
-                index = file.index('.html')
-                fileName = file[:index] + '_user.html'
+                index = htmlfile.index('.html')
+                fileName = htmlfile[:index] + '_user.html'
                 
            
             with open(fileName, 'w') as f:
