@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10347 2017-10-03 09:43:25Z Lavender $
+# $Id: setup.py 10368 2017-10-13 11:25:36Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-10-03 17:43:25 +0800 (週二, 03 十月 2017) $
-# $Revision: 10347 $ 
+# $Date: 2017-10-13 19:25:36 +0800 (週五, 13 十月 2017) $
+# $Revision: 10368 $ 
 
 import os
 import sys
@@ -158,7 +158,7 @@ else:
 def loadData(baseDir, language):
     logger.info("-----Start load data-----")
     data = os.path.join(".", 'fixtures', 'initial_data.json')
-    result = os.system("%s manage.py loaddata %s" % (sys.executable, data))
+    result = os.system("%s manage.py loaddata \"%s\"" % (sys.executable, data))
     
     if not result == 0:
         return False
@@ -182,7 +182,8 @@ def loadData(baseDir, language):
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(description='Path to Project')
-    parser.add_argument('path', metavar='path', type=str, help='path')
+    parser.add_argument(
+        'path', metavar='path', type=str, help='path', nargs='+')
     parser.add_argument(
         '-m', '--mode', 
         default='programmer',
@@ -204,7 +205,7 @@ if __name__ == "__main__":
     else:
         mode = 'user'
         
-    path = args.path
+    path = " ".join(args.path) 
     
     settingsPath = findSettings(path)
     
@@ -225,9 +226,11 @@ if __name__ == "__main__":
         path = os.path.join(path, projectName)
         
         if wizard:
-            result = os.system("djangocms -f -p %s %s -w" % (path, projectName))
+            result = os.system(
+                "djangocms -f -p \"%s\" \"%s\" -w" % (path, projectName))
         else:
-            result = os.system("djangocms -f -p %s %s" % (path, projectName))
+            result = os.system(
+                "djangocms -f -p \"%s\" \"%s\"" % (path, projectName))
             
         if not result == 0:
             print
